@@ -16,12 +16,12 @@ from pydantic import root_validator
 
 from .._shared import AddressType
 from .._shared import DictStrAny
+from .._shared import EmployeeRef
 from .._shared import EngagementRef
 from .._shared import MOBase
 from .._shared import OrganisationRef
 from .._shared import OrgUnitRef
 from .._shared import PersonRef
-from .._shared import UUIDBase
 from .._shared import Validity
 from .._shared import Visibility
 
@@ -31,7 +31,7 @@ from .._shared import Visibility
 # --------------------------------------------------------------------------------------
 
 
-class AddressBase(UUIDBase):
+class AddressBase(MOBase):
     """
     A MO address object.
     """
@@ -45,55 +45,62 @@ class AddressBase(UUIDBase):
 class AddressRead(AddressBase):
     """
     A MO address read object.
-    Note that one and only one of {person, org_unit, engagement} are given at any time.
+    Note that one and only one of {employee, org_unit, engagement} are given at any
+    time.
     """
 
-    address_type: UUID = Field(description="UUID of the address type klasse.")
-    person: Optional[UUID] = Field(
-        description="UUID of the person related to the address."
+    address_type_uuid: UUID = Field(description="UUID of the address type klasse.")
+    employee_uuid: Optional[UUID] = Field(
+        description="UUID of the employee related to the address."
     )
-    org_unit: Optional[UUID] = Field(
+    org_unit_uuid: Optional[UUID] = Field(
         description="UUID of the organisation unit related to the address."
     )
-    engagement: Optional[UUID] = Field("UUID of the engagement related to the address.")
-    visibility: Optional[UUID] = Field("UUID of the visibility klasse of the address.")
+    engagement_uuid: Optional[UUID] = Field(
+        description="UUID of the engagement related to the address."
+    )
+    visibility_uuid: Optional[UUID] = Field(
+        description="UUID of the visibility klasse of the address."
+    )
 
-    # NOTE: The one and only one of {person, org_unit, engagement} invariant
+    # NOTE: The one and only one of {employee, org_unit, engagement} invariant
     # is not validated here because reads are assumed to originate from valid data.
 
 
 class AddressWrite(AddressBase):
     """
     A MO address write object.
-    Note that one and only one of {person, org_unit, engagement} can be given.
+    Note that one and only one of {employee, org_unit, engagement} can be given.
     """
 
     address_type: AddressType = Field(
         description="Reference to the address type klasse."
     )
-    person: Optional[PersonRef] = Field(
-        description="Reference to the person for which the address should "
-        "be created."
+    employee: Optional[EmployeeRef] = Field(
+        description="Reference to the employee for which the address should be created."
     )
     org_unit: Optional[OrgUnitRef] = Field(
-        description="Reference to the organisation unit for which the address should "
-        "be created."
+        description=(
+            "Reference to the organisation unit for which the address should "
+            "be created."
+        )
     )
     engagement: Optional[EngagementRef] = Field(
-        description="Reference to the engagement for which the address should "
-        "be created."
+        description=(
+            "Reference to the engagement for which the address should be created."
+        )
     )
     visibility: Optional[Visibility] = Field(
         description="Reference to the Visibility klasse of the created address object."
     )
 
     # NOTE: This is not optimal handling of variability. In a perfect world,
-    # we'd have an object_ref: Union[PersonRef, OrgUnitRef, EngagementRef] field so that
-    # we do not have to check it like this.
+    # we'd have an object_ref: Union[EmployeeRef, OrgUnitRef, EngagementRef]
+    # field so that we do not have to check it like this.
     @root_validator
     def validate_references(cls, values: DictStrAny) -> DictStrAny:
         references = (
-            values.get("person"),
+            values.get("employee"),
             values.get("org_unit"),
             values.get("engagement"),
         )
@@ -122,20 +129,26 @@ class Address(MOBase):
         description="Reference to the address type facet."
     )
     org: Optional[OrganisationRef] = Field(
-        description="Reference to the organisation under which the address should "
-        "be created. MO only supports one organisation, so this is rarely used."
+        description=(
+            "Reference to the organisation under which the address should be created. "
+            "MO only supports one organisation, so this is rarely used."
+        )
     )
     person: Optional[PersonRef] = Field(
-        description="Reference to the person object for which the address should "
-        "be created."
+        description=(
+            "Reference to the person object for which the address should be created."
+        )
     )
     org_unit: Optional[OrgUnitRef] = Field(
-        description="Reference to the organisation unit for which the address should "
-        "be created."
+        description=(
+            "Reference to the organisation unit for which the address should be "
+            "created."
+        )
     )
     engagement: Optional[EngagementRef] = Field(
-        description="Reference to the engagement for which the address should "
-        "be created."
+        description=(
+            "Reference to the engagement for which the address should be created."
+        )
     )
     validity: Validity = Field(description="Validity of the created address object.")
     visibility: Optional[Visibility] = Field(
