@@ -12,70 +12,78 @@ from uuid import UUID
 
 from pydantic import Field
 
+from .._shared import EmployeeRef
 from .._shared import ITSystemRef
 from .._shared import MOBase
 from .._shared import OrgUnitRef
 from .._shared import PersonRef
 from .._shared import Validity
 
-
 # --------------------------------------------------------------------------------------
 # IT Systems
 # --------------------------------------------------------------------------------------
 
 
-class ITSystemBindingBase(MOBase):
-    """A MO IT system binding object."""
+class ITSystemRead(MOBase):
+    """Payload model for IT systems."""
+
+    type_: str = Field("itsystem", alias="type", description="The object type")
+    name: str = Field(description="Name/titel of the itsystem.")
+    user_key: str = Field(description="Short, unique key.")
+    system_type: Optional[str] = Field(description="The ITSystem type.")
+
+
+# --------------------------------------------------------------------------------------
+# IT Users
+# --------------------------------------------------------------------------------------
+
+
+class ITUserBase(MOBase):
+    """A MO IT user object."""
 
     type_: str = Field("it", alias="type", description="The object type.")
-    validity: Validity = Field(description="Validity of the IT system binding object.")
+    validity: Validity = Field(description="Validity of the IT user object.")
 
 
-class ITSystemBindingRead(ITSystemBindingBase):
-    """A MO IT system binding read object."""
+class ITUserRead(ITUserBase):
+    """A MO IT user read object."""
 
-    itsystem: UUID = Field(description="UUID of the IT system of the binding.")
-    person: Optional[UUID] = Field(
-        description="Reference to the person related to the binding."
+    itsystem_uuid: UUID = Field(description="UUID of the ITSystem related to the user.")
+    employee_uuid: Optional[UUID] = Field(
+        description="UUID of the employee related to the user."
     )
-    org_unit: Optional[UUID] = Field(
-        description="Reference to the organisation unit related to the binding."
+    org_unit_uuid: Optional[UUID] = Field(
+        description="UUID organisation unit related to the user."
     )
 
 
-class ITSystemBindingWrite(ITSystemBindingBase):
-    """A MO IT system binding write object."""
+class ITUserWrite(ITUserBase):
+    """A MO IT user write object."""
 
     itsystem: ITSystemRef = Field(
-        description="The IT system for which to create this binding."
+        description="Reference to the IT system for the IT user."
     )
-    person: Optional[PersonRef] = Field(
-        description="Reference to the person object for which the binding should "
-        "be created."
+    employee: Optional[EmployeeRef] = Field(
+        description="Reference to the employee for the IT user."
     )
     org_unit: Optional[OrgUnitRef] = Field(
-        description="Reference to the organisation unit for which the binding should "
-        "be created."
+        description="Reference to the organisation unit for the IT user."
     )
 
 
-class ITSystemBinding(MOBase):
+class ITUser(MOBase):
     type_: Literal["it"] = Field("it", alias="type", description="The object type.")
-    user_key: str = Field(description="The IT system account name.")
+    user_key: str = Field(description="The IT user account name.")
     itsystem: ITSystemRef = Field(
-        description="The IT system for which to create this binding."
+        description="Reference to the IT system for the IT user."
     )
     person: Optional[PersonRef] = Field(
-        description="Reference to the person object for which the binding should "
-        "be created."
+        description="Reference to the person for the IT user."
     )
     org_unit: Optional[OrgUnitRef] = Field(
-        description="Reference to the organisation unit for which the binding should "
-        "be created."
-    )
-    validity: Validity = Field(
-        description="Validity of the created IT system binding object."
+        description="Reference to the organisation unit for the IT user."
     )
+    validity: Validity = Field(description="Validity of the created IT user object.")
 
     @classmethod
     def from_simplified_fields(
@@ -87,11 +95,8 @@ class ITSystemBinding(MOBase):
         to_date: Optional[str] = None,
         person_uuid: Optional[UUID] = None,
         org_unit_uuid: Optional[UUID] = None,
-    ) -> "ITSystemBinding":
-        """
-        Create an IT System Binding from simplified fields.
-        """
-
+    ) -> "ITUser":
+        """Create an IT User from simplified fields."""
         it_system = ITSystemRef(uuid=itsystem_uuid)
         person = PersonRef(uuid=person_uuid) if person_uuid else None
         org_unit = OrgUnitRef(uuid=org_unit_uuid) if org_unit_uuid else None
