@@ -13,6 +13,7 @@ from uuid import UUID
 
 from pydantic import Field
 
+from .._shared import EmployeeRef
 from .._shared import ManagerLevel
 from .._shared import ManagerType
 from .._shared import MOBase
@@ -41,15 +42,15 @@ class ManagerBase(MOBase):
 class ManagerRead(ManagerBase):
     """A MO ManagerRead object."""
 
-    org_unit: UUID = Field(
+    org_unit_uuid: UUID = Field(
         description="UUID of the organisation unit related to the manager."
     )
-    person: Optional[UUID] = Field(
-        description="UUID of the person related to the manager."
+    employee_uuid: Optional[UUID] = Field(
+        description="UUID of the employee related to the manager."
     )
-    manager_type: Optional[UUID] = Field(description="UUID of the manager type.")
-    manager_level: Optional[UUID] = Field(description="UUID of the manager level.")
-    responsibility: Optional[List[UUID]] = Field(
+    manager_type_uuid: Optional[UUID] = Field(description="UUID of the manager type.")
+    manager_level_uuid: Optional[UUID] = Field(description="UUID of the manager level.")
+    responsibility_uuids: Optional[List[UUID]] = Field(
         description="List of UUID's of the responsibilities."
     )
 
@@ -60,8 +61,8 @@ class ManagerWrite(ManagerBase):
     org_unit: OrgUnitRef = Field(
         description="Reference to the organisation unit for the manager."
     )
-    person: Optional[PersonRef] = Field(
-        description="Reference to the person that will be the resulting manager."
+    employee: Optional[EmployeeRef] = Field(
+        description="Reference to the employee that will be the resulting manager."
     )
     manager_level: Optional[ManagerLevel] = Field(
         description="Reference to the manager level klasse for the created manager."
@@ -81,8 +82,10 @@ class Manager(MOBase):
         "manager", alias="type", description="The object type."
     )
     org_unit: OrgUnitRef = Field(
-        description="Reference to the organisation unit "
-        "for which the manager should be created."
+        description=(
+            "Reference to the organisation unit "
+            "for which the manager should be created."
+        )
     )
     person: PersonRef = Field(
         description="Reference to the person that will be the resulting manager."
@@ -101,7 +104,6 @@ class Manager(MOBase):
     @classmethod
     def from_simplified_fields(
         cls,
-        uuid: UUID,
         org_unit_uuid: UUID,
         person_uuid: UUID,
         responsibility_uuids: List[UUID],
@@ -109,6 +111,7 @@ class Manager(MOBase):
         manager_type_uuid: UUID,
         from_date: str,
         to_date: Optional[str] = None,
+        uuid: Optional[UUID] = None,
     ) -> "Manager":
         """Create a manager from simplified fields."""
         person = PersonRef(uuid=person_uuid)
